@@ -41,8 +41,6 @@
 
 #define KDESU_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
-#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
-
 /* Take any defaults from group settings */
 #if !defined(KDESU_NO_DEPRECATED) && !defined(KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -86,7 +84,7 @@
 #define KDESU_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDESU_NO_DEPRECATED
-#  define KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56800
+#  define KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
 #endif
 #ifdef KDESU_NO_DEPRECATED_WARNINGS
 #  define KDESU_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +94,7 @@
 #  ifdef KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDESU_DEPRECATED_WARNINGS_SINCE KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDESU_DEPRECATED_WARNINGS_SINCE 0x56800
+#    define KDESU_DEPRECATED_WARNINGS_SINCE 0x56a00
 #  endif
 #endif
 
@@ -105,7 +103,7 @@
 #endif
 
 #ifdef KDESU_DEPRECATED
-#  define KDESU_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KDESU_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KDESU_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
